pub struct CanonicalEventStream { /* private fields */ }Expand description
Cloneable receiver handle for canonical events from one Interpretation.
Implementations
Sourceimpl CanonicalEventStream
impl CanonicalEventStream
Sourcepub async fn recv(&self) -> Option<InterpreterOutputEvent>
pub async fn recv(&self) -> Option<InterpreterOutputEvent>
Receive the next event. None when the stream is closed after terminal end
was already delivered (or the owner dropped without end — treated as loss).