CompletedSentence

Struct CompletedSentence 

pub struct CompletedSentence {
    pub content: String,
    pub content_bytes: usize,
    pub bytes_consumed: usize,
}
One completed sentence from the segmenter, with buffer consumption.

Fields

content: String

Sentence text (trimmed trailing whitespace).

content_bytes: usize

Bytes of the content region (through terminator, excluding following whitespace). Used for dialect source-time attribution.

bytes_consumed: usize

Bytes removed from the assembly buffer for this sentence (content region + trailing whitespace after the terminator).